@@ -61,11 +61,14 @@ import com.openexchange.mobile.api.facade.connectors.impl.AllFoldersConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ClearFolderConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ConfigConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ContactsConnector;
+import com.openexchange.mobile.api.facade.connectors.impl.CreateAccountConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.CreateFolderConnector;
+import com.openexchange.mobile.api.facade.connectors.impl.DeleteAccountConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.DeleteFolderConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.DeleteMailsConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.EnvelopesConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ExamineMultipleFoldersConnector;
+import com.openexchange.mobile.api.facade.connectors.impl.GetAccountConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.GetJsLobConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.GetMailConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ManifestsConnector;
@@ -77,13 +80,18 @@ import com.openexchange.mobile.api.facade.connectors.impl.SetColorsConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.StubsConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ThreadReferencesConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ThreadedAllStubsConnector;
+import com.openexchange.mobile.api.facade.connectors.impl.UpdateAccountConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.UserConnector;
+import com.openexchange.mobile.api.facade.connectors.impl.ValidateAccountConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.VersionConnector;
 import com.openexchange.mobile.api.facade.models.Folder;
+import com.openexchange.mobile.api.facade.models.MailAccountData;
 import com.openexchange.mobile.api.facade.models.MailFlags;
 
 public interface ConnectorFactory {
 
+    GetAccountConnector getAccountConnector(SessionData sessionData, String accountId);
+
     AccountsConnector getAccountsConnector(SessionData sessionData);
 
     AllCapabilitiesConnector getAllCapabilities(SessionData sessionData);
@@ -98,6 +106,8 @@ public interface ConnectorFactory {
 
     CreateFolderConnector getCreateFolderConnector(SessionData sessionData, String parentFolderId, String name);
 
+    DeleteAccountConnector getDeleteAccountConnector(SessionData sessionData, String accountId);
+
     DeleteFolderConnector getDeleteFolderConnector(SessionData sessionData, String folderId);
 
     DeleteMailsConnector getDeleteMailsConnector(SessionData sessionData, String folderId, List<String> mailIds, boolean purge);
@@ -118,6 +128,8 @@ public interface ConnectorFactory {
 
     ManifestsConnector getManifestsConnector();
 
+    CreateAccountConnector getCreateAccountConnector(SessionData sessionData, MailAccountData account);
+
     MoveMailsConnector getMoveMailsConnector(SessionData sessionData, String folderId, List<String> mailIds, String targetFolderId);
 
     PnsSubscribeConnector getPnsSubscribeConnector(SessionData sessionData, String transport, String token, List<String> tokens);
@@ -134,8 +146,12 @@ public interface ConnectorFactory {
 
     ThreadReferencesConnector getThreadReferencesConnector(SessionData sessionData, String folderId);
 
+    UpdateAccountConnector getUpdateAccountConnector(SessionData sessionData, MailAccountData account);
+
     UserConnector getUserConnector(SessionData sessionData);
 
+    ValidateAccountConnector getValidateAccountConnector(SessionData sessionData, MailAccountData account, boolean forceInsecureConnection);
+
     VersionConnector getVersionConnector();
 
 }
