@@ -61,7 +61,6 @@ import javax.ws.rs.Produces;
 import javax.ws.rs.core.Context;
 import javax.ws.rs.core.MediaType;
 import javax.ws.rs.core.Response;
-import javax.ws.rs.core.Response.ResponseBuilder;
 
 import com.openexchange.java.Strings;
 import com.openexchange.mobile.api.facade.auth.AuthenticationService;
@@ -112,16 +111,12 @@ public class AuthenticationEndpoint {
         validate(authenticationRequestBody);
         String hostname = RequestUtil.getHostHeader(request);
         String userAgent = RequestUtil.getUserAgent(request);
-        String forwardedFor = RequestUtil.getForwardedForWithRemoteIp(request);
-        String proto = RequestUtil.getForwardedProto(request);
         String trackingId = RequestUtil.getTrackingId(request);
         HostConfiguration configuration = ConfigurationHelper.getConfiguration(hostname);
         RequestUtil.checkUserAgent(userAgent, configuration);
         LoginCredentials credentials = getCredentials(request, authenticationRequestBody)
                 .withHost(hostname)
                 .withUserAgent(userAgent)
-                .withForwardedFor(forwardedFor)
-                .withForwardedProto(proto)
                 .withTrackingId(trackingId);
         try {
             AuthenticationService authenticationService = authenticationHandler.getAuthenticationService(configuration);
@@ -170,8 +165,8 @@ public class AuthenticationEndpoint {
     @Consumes(MediaType.APPLICATION_JSON)
     @Produces(MediaType.APPLICATION_JSON)
     public Response logout(@Context HttpServletRequest request, String rawRequestBody) {
-        SessionData sessionData = RequestUtil.getSessionData(request);
         log.info("Logging out client");
+        SessionData sessionData = RequestUtil.getSessionData(request);
         HostConfiguration configuration = sessionData.getConfiguration();
         AuthenticationService authenticationService = authenticationHandler.getAuthenticationService(configuration);
         LogoutRequestBody requestBody = Strings.isEmpty(rawRequestBody)
@@ -196,14 +191,13 @@ public class AuthenticationEndpoint {
         String rawResponseBody = JacksonUtil.toString(responseBody);
         Response.ResponseBuilder builder = Response.ok(rawResponseBody);
         CookieUtil.addToResponse(builder, sessionData.getCookies());
-        return RequestUtil.nonCachable(builder).build();
+        return builder.build();
     }
 
     @SneakyThrows
     private Response buildRedirectResponse(ApiFacadeException e) {
         String baseUrl = e.getMessage();
-        ResponseBuilder builder = Response.temporaryRedirect(new URI(baseUrl));
-        return RequestUtil.nonCachable(builder).build();
+        return Response.temporaryRedirect(new URI(baseUrl)).build();
     }
 
 }
