@@ -273,7 +273,7 @@ public class MailAccountData {
         archiveFolderId = accountMto.getArchiveFolderId();
         unifiedInboxEnabled = accountMto.getUnifiedInboxEnabled();
 
-        canSend = (accountMto.getId() != null && "0".equals(accountMto.getId().toString())) || !Strings.isEmpty(accountMto.getTransportUrl());
+        canSend = "0".equals(accountMto.getId().toString()) || !Strings.isEmpty(accountMto.getTransportUrl());
 
         folders = null;
         standardFolders = null;
@@ -326,8 +326,4 @@ public class MailAccountData {
         return "0".equals(id);
     }
 
-    public boolean isPop3Account() {
-        return mailProtocol != null && mailProtocol.startsWith("pop3");
-    }
-
 }
