@@ -99,9 +99,6 @@ public class ConfigService {
         capabilities.addAll(remoteCapabilities);
         capabilities.add(new Capability("facade_accounts_sync"));
         capabilities.add(new Capability("facade_accounts_crud"));
-        if (sessionData.getConfiguration().isReturnNonPrimaryAccounts()) {
-            capabilities.add(new Capability("facade_multiple_accounts_enabled"));
-        }
         return capabilities;
     }
 
